@@ -1,4 +1,22 @@
-/* -*- mode: C; c-basic-offset: 4 -*- */
+/* -*- mode: C; c-basic-offset: 4 -*-
+ * pyorbit - a Python language mapping for the ORBit2 CORBA ORB
+ * Copyright (C) 2002  James Henstridge <james@daa.com.au>
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+*/
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -184,38 +202,29 @@ generate_exception_stub(CORBA_TypeCode tc)
     return exception;
 }
 
-static void
+static PyObject *
 generate_enum_stub(CORBA_TypeCode tc)
 {
     PyObject *container;
-    PyObject *subnames;
+    PyObject *stub, *values;
     gchar *pyname;
     gint i;
 
     container = _pyorbit_get_container(tc->repo_id, FALSE);
     if (!container)
-	return;
+	return NULL;
 
-    /* how to get the enum values? */
-    subnames = PyTuple_New(tc->sub_parts);
+    stub = _pyorbit_generate_enum(tc, &values);
     for (i = 0; i < tc->sub_parts; i++) {
-	PyObject *item = PyString_FromString(tc->subnames[i]);
-
-	PyTuple_SetItem(subnames, i, item);
-
-	/* add the enum flag itself */
-	item = PyInt_FromLong(i);
+	PyObject *item = PyTuple_GetItem(values, i);
 	pyname = _pyorbit_escape_name(tc->subnames[i]);
 	PyObject_SetAttrString(container, pyname, item);
 	g_free(pyname);
-	Py_DECREF(item);
     }
 
-    pyname = _pyorbit_escape_name(tc->name);
-    PyObject_SetAttrString(container, pyname, subnames);
-    g_free(pyname);
-    Py_DECREF(subnames);
     Py_DECREF(container);
+
+    return stub;
 }
 
 void
@@ -250,7 +259,7 @@ pyorbit_generate_typecode_stubs(CORBA_TypeCode tc)
 	stub = generate_union_stub(tc);
 	break;
     case CORBA_tk_enum:
-	generate_enum_stub(tc);
+	stub = generate_enum_stub(tc);
 	break;
     case CORBA_tk_string:
     case CORBA_tk_sequence:
